pub enum DebugRequest {
ConnectTarget {
target_id: u8,
server: ServerEnd<DeviceMarker>,
responder: DebugConnectTargetResponder,
},
GetControllerProperties {
responder: DebugGetControllerPropertiesResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: DebugControlHandle,
method_type: MethodType,
},
}Variants
ConnectTarget
Connects to the target device with the given ID. Equivalent to connecting to TargetService
via the corresponding driver node.
Returns INVALID_ARGS if target_id is greater than or equal to MAX_TARGETS.
May return an error if there is no such target on the bus; otherwise errors will be returned
when attempting to access the client.
GetControllerProperties
Returns the properties of the host SPMI controller.
Fields

responder: DebugGetControllerPropertiesResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: DebugControlHandle
method_type: MethodTypeImplementations
Sourceimpl DebugRequest
impl DebugRequest
pub fn into_connect_target( self, ) -> Option<(u8, ServerEnd<DeviceMarker>, DebugConnectTargetResponder)>
pub fn into_get_controller_properties( self, ) -> Option<DebugGetControllerPropertiesResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL