pub enum SubTargetServiceRequest {
Device(DeviceRequestStream),
}Expand description
A request for one of the member protocols of SubTargetService.
This service represents a sub-target device within an SPMI target. Clients have access to a subset of the SPMI register range as determined by the controller driver.
Variants
Device(DeviceRequestStream)