pub struct DebugConnectTargetRequest {
pub target_id: u8,
pub server: ServerEnd<DeviceMarker>,
}Fields
target_id: u8server: ServerEnd<DeviceMarker>Trait Implementations
Sourceimpl Debug for DebugConnectTargetRequest
impl Debug for DebugConnectTargetRequest
Sourceimpl Decode<DebugConnectTargetRequest, DefaultFuchsiaResourceDialect> for DebugConnectTargetRequest
impl Decode<DebugConnectTargetRequest, DefaultFuchsiaResourceDialect> for DebugConnectTargetRequest
Sourceimpl Encode<DebugConnectTargetRequest, DefaultFuchsiaResourceDialect> for &mut DebugConnectTargetRequest
impl Encode<DebugConnectTargetRequest, DefaultFuchsiaResourceDialect> for &mut DebugConnectTargetRequest
Sourceimpl<T0: Encode<u8, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<DeviceMarker>>, DefaultFuchsiaResourceDialect>> Encode<DebugConnectTargetRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<u8, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<DeviceMarker>>, DefaultFuchsiaResourceDialect>> Encode<DebugConnectTargetRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
Sourceimpl Hash for DebugConnectTargetRequest
impl Hash for DebugConnectTargetRequest
Sourceimpl Ord for DebugConnectTargetRequest
impl Ord for DebugConnectTargetRequest
Sourcefn cmp(&self, other: &DebugConnectTargetRequest) -> Ordering
fn cmp(&self, other: &DebugConnectTargetRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DebugConnectTargetRequest
impl PartialEq for DebugConnectTargetRequest
Sourcefn eq(&self, other: &DebugConnectTargetRequest) -> bool
fn eq(&self, other: &DebugConnectTargetRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DebugConnectTargetRequest
impl PartialOrd for DebugConnectTargetRequest
Sourceimpl ResourceTypeMarker for DebugConnectTargetRequest
impl ResourceTypeMarker for DebugConnectTargetRequest
Sourcetype Borrowed<'a> = &'a mut DebugConnectTargetRequest
type Borrowed<'a> = &'a mut DebugConnectTargetRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for DebugConnectTargetRequest
impl TypeMarker for DebugConnectTargetRequest
Sourcetype Owned = DebugConnectTargetRequest
type Owned = DebugConnectTargetRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for DebugConnectTargetRequest
impl Standalone<DefaultFuchsiaResourceDialect> for DebugConnectTargetRequest
impl StructuralPartialEq for DebugConnectTargetRequest