pub struct DebugGetControllerPropertiesResponder { /* private fields */ }Implementations
Sourceimpl DebugGetControllerPropertiesResponder
impl DebugGetControllerPropertiesResponder
Sourcepub fn send(
self,
payload: &DebugGetControllerPropertiesResponse,
) -> Result<(), Error>
pub fn send( self, payload: &DebugGetControllerPropertiesResponse, ) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
payload: &DebugGetControllerPropertiesResponse,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, payload: &DebugGetControllerPropertiesResponse, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.