pub struct DebugProxy { /* private fields */ }Implementations
Sourceimpl DebugProxy
impl DebugProxy
Sourcepub fn take_event_stream(&self) -> DebugEventStream
pub fn take_event_stream(&self) -> DebugEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn connect_target(
&self,
target_id: u8,
server: ServerEnd<DeviceMarker>,
) -> QueryResponseFut<DebugConnectTargetResult, DefaultFuchsiaResourceDialect>
pub fn connect_target( &self, target_id: u8, server: ServerEnd<DeviceMarker>, ) -> QueryResponseFut<DebugConnectTargetResult, DefaultFuchsiaResourceDialect>
Connects to the target device with the given ID. Equivalent to connecting to TargetService
via the corresponding driver node.
Returns INVALID_ARGS if target_id is greater than or equal to MAX_TARGETS.
May return an error if there is no such target on the bus; otherwise errors will be returned
when attempting to access the client.
Sourcepub fn get_controller_properties(
&self,
) -> QueryResponseFut<DebugGetControllerPropertiesResponse, DefaultFuchsiaResourceDialect>
pub fn get_controller_properties( &self, ) -> QueryResponseFut<DebugGetControllerPropertiesResponse, DefaultFuchsiaResourceDialect>
Returns the properties of the host SPMI controller.