pub struct DebugSynchronousProxy { /* private fields */ }Implementations
Sourceimpl DebugSynchronousProxy
impl DebugSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DebugEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DebugEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn connect_target(
&self,
target_id: u8,
server: ServerEnd<DeviceMarker>,
___deadline: MonotonicInstant,
) -> Result<DebugConnectTargetResult, Error>
pub fn connect_target( &self, target_id: u8, server: ServerEnd<DeviceMarker>, ___deadline: MonotonicInstant, ) -> Result<DebugConnectTargetResult, Error>
Connects to the target device with the given ID. Equivalent to connecting to TargetService
via the corresponding driver node.
Returns INVALID_ARGS if target_id is greater than or equal to MAX_TARGETS.
May return an error if there is no such target on the bus; otherwise errors will be returned
when attempting to access the client.
Sourcepub fn get_controller_properties(
&self,
___deadline: MonotonicInstant,
) -> Result<DebugGetControllerPropertiesResponse, Error>
pub fn get_controller_properties( &self, ___deadline: MonotonicInstant, ) -> Result<DebugGetControllerPropertiesResponse, Error>
Returns the properties of the host SPMI controller.