pub struct DeviceRegisterReadResponder { /* private fields */ }Implementations
Sourceimpl DeviceRegisterReadResponder
impl DeviceRegisterReadResponder
Sourcepub fn send(self, result: Result<&[u8], DriverError>) -> Result<(), Error>
pub fn send(self, result: Result<&[u8], DriverError>) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
result: Result<&[u8], DriverError>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, result: Result<&[u8], DriverError>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.