DeviceSynchronousProxy

Struct DeviceSynchronousProxy 

pub struct DeviceSynchronousProxy { /* private fields */ }

Implementations

Source

impl DeviceSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DeviceEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn register_read( &self, address: u16, size_bytes: u32, ___deadline: MonotonicInstant, ) -> Result<DeviceRegisterReadResult, Error>

Issue register read commands to the SPMI device. The implementation may choose which SPMI variation (e.g. extended, long) to use. When successful, it returns size_bytes in data read contiguously starting from address in the device.

pub fn register_write( &self, address: u16, data: &[u8], ___deadline: MonotonicInstant, ) -> Result<DeviceRegisterWriteResult, Error>

Issue register write commands to the SPMI device. The implementation may choose which SPMI variation (e.g. extended, long) to use. When this command is successful, data will be written contiguously starting from address in the device.

pub fn get_properties( &self, ___deadline: MonotonicInstant, ) -> Result<DeviceGetPropertiesResponse, Error>

Get the properties of the SPMI device.

pub fn watch_controller_write_commands( &self, address: u8, size: u16, setup_wake_lease: Option<EventPair>, ___deadline: MonotonicInstant, ) -> Result<DeviceWatchControllerWriteCommandsResult, Error>

Hanging-get method to receive controller write commands from the device. address and size specify the register range to monitor for commands. Multiple overlapping calls to this method are not allowed. Returns INVALID_ARGS if address or size are invalid, or BAD_STATE if another call is pending for this register range. Returns CANCELED if CancelWatchControllerWriteCommands() was called for this register range.

If this method is meant to keep the system awake (prevents suspension) while watch is setup, use the passed-in setup_wake_lease LeaseToken. Then, when the watch is triggered this method will return a second wake_lease LeaseToken to prevent suspension.

These keep alive wake lease tokens are provided by the Power Framework’s System Activity Governor. A driver supporting keep alive must be able to get wake_lease from System Activity Governor.

When wake_lease is closed, then the created wake lease keeping the system from suspending at the time of watch triggering is dropped. Hence, to guarantee that the system is not suspended by the Power Framework a client must either keep this wake_lease for as long as the system needs to stay awake, or a client must get its own wake lease from the Power Framework before it drops wake_lease to prevent suspension.

pub fn cancel_watch_controller_write_commands( &self, address: u8, size: u16, ___deadline: MonotonicInstant, ) -> Result<DeviceCancelWatchControllerWriteCommandsResult, Error>

Cancels an pending call to WatchControllerWriteCommands. address and size must exactly match a previous call to WatchControllerWriteCommands(), otherwise NOT_FOUND is returned.