pub struct DeviceWatchControllerWriteCommandsResponder { /* private fields */ }Implementations
Sourceimpl DeviceWatchControllerWriteCommandsResponder
impl DeviceWatchControllerWriteCommandsResponder
Sourcepub fn send(
self,
result: Result<(&[Register8], Option<EventPair>), DriverError>,
) -> Result<(), Error>
pub fn send( self, result: Result<(&[Register8], Option<EventPair>), DriverError>, ) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
result: Result<(&[Register8], Option<EventPair>), DriverError>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, result: Result<(&[Register8], Option<EventPair>), DriverError>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.