pub struct DeviceWatchControllerWriteCommandsResponse {
pub writes: Vec<Register8>,
pub wake_lease: Option<EventPair>,
}Fields
writes: Vec<Register8>wake_lease: Option<EventPair>Trait Implementations
Sourceimpl Decode<DeviceWatchControllerWriteCommandsResponse, DefaultFuchsiaResourceDialect> for DeviceWatchControllerWriteCommandsResponse
impl Decode<DeviceWatchControllerWriteCommandsResponse, DefaultFuchsiaResourceDialect> for DeviceWatchControllerWriteCommandsResponse
Sourceimpl Encode<DeviceWatchControllerWriteCommandsResponse, DefaultFuchsiaResourceDialect> for &mut DeviceWatchControllerWriteCommandsResponse
impl Encode<DeviceWatchControllerWriteCommandsResponse, DefaultFuchsiaResourceDialect> for &mut DeviceWatchControllerWriteCommandsResponse
Sourceimpl<T0: Encode<Vector<Register8, 256>, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<EventPair, { _ }, 16387>>, DefaultFuchsiaResourceDialect>> Encode<DeviceWatchControllerWriteCommandsResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<Vector<Register8, 256>, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<EventPair, { _ }, 16387>>, DefaultFuchsiaResourceDialect>> Encode<DeviceWatchControllerWriteCommandsResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
Sourceimpl Ord for DeviceWatchControllerWriteCommandsResponse
impl Ord for DeviceWatchControllerWriteCommandsResponse
Sourcefn cmp(&self, other: &DeviceWatchControllerWriteCommandsResponse) -> Ordering
fn cmp(&self, other: &DeviceWatchControllerWriteCommandsResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceWatchControllerWriteCommandsResponse
impl PartialEq for DeviceWatchControllerWriteCommandsResponse
Sourcefn eq(&self, other: &DeviceWatchControllerWriteCommandsResponse) -> bool
fn eq(&self, other: &DeviceWatchControllerWriteCommandsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceWatchControllerWriteCommandsResponse
impl PartialOrd for DeviceWatchControllerWriteCommandsResponse
Sourcefn partial_cmp(
&self,
other: &DeviceWatchControllerWriteCommandsResponse,
) -> Option<Ordering>
fn partial_cmp( &self, other: &DeviceWatchControllerWriteCommandsResponse, ) -> Option<Ordering>
Sourceimpl ResourceTypeMarker for DeviceWatchControllerWriteCommandsResponse
impl ResourceTypeMarker for DeviceWatchControllerWriteCommandsResponse
Sourcetype Borrowed<'a> = &'a mut DeviceWatchControllerWriteCommandsResponse
type Borrowed<'a> = &'a mut DeviceWatchControllerWriteCommandsResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for DeviceWatchControllerWriteCommandsResponse
impl TypeMarker for DeviceWatchControllerWriteCommandsResponse
Sourcetype Owned = DeviceWatchControllerWriteCommandsResponse
type Owned = DeviceWatchControllerWriteCommandsResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for DeviceWatchControllerWriteCommandsResponse
impl Standalone<DefaultFuchsiaResourceDialect> for DeviceWatchControllerWriteCommandsResponse
impl StructuralPartialEq for DeviceWatchControllerWriteCommandsResponse