pub struct SubTargetServiceMarker;Trait Implementations
Sourceimpl Clone for SubTargetServiceMarker
impl Clone for SubTargetServiceMarker
Sourcefn clone(&self) -> SubTargetServiceMarker
fn clone(&self) -> SubTargetServiceMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubTargetServiceMarker
impl Debug for SubTargetServiceMarker
Sourceimpl Hash for SubTargetServiceMarker
impl Hash for SubTargetServiceMarker
Sourceimpl Ord for SubTargetServiceMarker
impl Ord for SubTargetServiceMarker
Sourcefn cmp(&self, other: &SubTargetServiceMarker) -> Ordering
fn cmp(&self, other: &SubTargetServiceMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SubTargetServiceMarker
impl PartialEq for SubTargetServiceMarker
Sourcefn eq(&self, other: &SubTargetServiceMarker) -> bool
fn eq(&self, other: &SubTargetServiceMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SubTargetServiceMarker
impl PartialOrd for SubTargetServiceMarker
Sourceimpl ServiceMarker for SubTargetServiceMarker
Available on Fuchsia only.
impl ServiceMarker for SubTargetServiceMarker
Available on Fuchsia only.
Sourceconst SERVICE_NAME: &'static str = "fuchsia.hardware.spmi.SubTargetService"
const SERVICE_NAME: &'static str = "fuchsia.hardware.spmi.SubTargetService"
The name of the service. Used for service lookup and discovery.
Sourcetype Proxy = SubTargetServiceProxy
type Proxy = SubTargetServiceProxy
The type of the proxy object upon which calls are made to a remote FIDL service.
Sourcetype Request = SubTargetServiceRequest
type Request = SubTargetServiceRequest
The request type for this particular FIDL service.
impl Copy for SubTargetServiceMarker
impl Eq for SubTargetServiceMarker
impl StructuralPartialEq for SubTargetServiceMarker