pub struct SubTargetServiceProxy(/* private fields */);Expand description
This service represents a sub-target device within an SPMI target. Clients have access to a subset of the SPMI register range as determined by the controller driver.
Implementations
Sourceimpl SubTargetServiceProxy
impl SubTargetServiceProxy
pub fn connect_to_device(&self) -> Result<DeviceProxy, Error>
Sourcepub fn connect_to_device_sync(&self) -> Result<DeviceSynchronousProxy, Error>
pub fn connect_to_device_sync(&self) -> Result<DeviceSynchronousProxy, Error>
Like connect_to_device, but returns a sync proxy.
See Self::connect_to_device for more details.
Sourcepub fn connect_channel_to_device(
&self,
server_end: ServerEnd<DeviceMarker>,
) -> Result<(), Error>
pub fn connect_channel_to_device( &self, server_end: ServerEnd<DeviceMarker>, ) -> Result<(), Error>
Like connect_to_device, but accepts a server end.
See Self::connect_to_device for more details.
pub fn instance_name(&self) -> &str