pub struct TargetServiceMarker;Trait Implementations
Sourceimpl Clone for TargetServiceMarker
impl Clone for TargetServiceMarker
Sourcefn clone(&self) -> TargetServiceMarker
fn clone(&self) -> TargetServiceMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetServiceMarker
impl Debug for TargetServiceMarker
Sourceimpl Hash for TargetServiceMarker
impl Hash for TargetServiceMarker
Sourceimpl Ord for TargetServiceMarker
impl Ord for TargetServiceMarker
Sourcefn cmp(&self, other: &TargetServiceMarker) -> Ordering
fn cmp(&self, other: &TargetServiceMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TargetServiceMarker
impl PartialEq for TargetServiceMarker
Sourcefn eq(&self, other: &TargetServiceMarker) -> bool
fn eq(&self, other: &TargetServiceMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TargetServiceMarker
impl PartialOrd for TargetServiceMarker
Sourceimpl ServiceMarker for TargetServiceMarker
Available on Fuchsia only.
impl ServiceMarker for TargetServiceMarker
Available on Fuchsia only.
Sourceconst SERVICE_NAME: &'static str = "fuchsia.hardware.spmi.TargetService"
const SERVICE_NAME: &'static str = "fuchsia.hardware.spmi.TargetService"
The name of the service. Used for service lookup and discovery.
Sourcetype Proxy = TargetServiceProxy
type Proxy = TargetServiceProxy
The type of the proxy object upon which calls are made to a remote FIDL service.
Sourcetype Request = TargetServiceRequest
type Request = TargetServiceRequest
The request type for this particular FIDL service.
impl Copy for TargetServiceMarker
impl Eq for TargetServiceMarker
impl StructuralPartialEq for TargetServiceMarker