pub enum DeviceRequest {
RegisterRead {
address: u16,
size_bytes: u32,
responder: DeviceRegisterReadResponder,
},
RegisterWrite {
address: u16,
data: Vec<u8>,
responder: DeviceRegisterWriteResponder,
},
GetProperties {
responder: DeviceGetPropertiesResponder,
},
WatchControllerWriteCommands {
address: u8,
size: u16,
setup_wake_lease: Option<EventPair>,
responder: DeviceWatchControllerWriteCommandsResponder,
},
CancelWatchControllerWriteCommands {
address: u8,
size: u16,
responder: DeviceCancelWatchControllerWriteCommandsResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: DeviceControlHandle,
method_type: MethodType,
},
}Expand description
Each instance of Device represents a target/secondary SPMI device on a SPMI bus.
To support multiple SPMI devices, multiple nodes must be instantiated.
Variants
RegisterRead
Issue register read commands to the SPMI device.
The implementation may choose which SPMI variation (e.g. extended, long) to use.
When successful, it returns size_bytes in data read contiguously starting from
address in the device.
RegisterWrite
Issue register write commands to the SPMI device.
The implementation may choose which SPMI variation (e.g. extended, long) to use.
When this command is successful, data will be written contiguously starting from
address in the device.
GetProperties
Get the properties of the SPMI device.
Fields
responder: DeviceGetPropertiesResponderWatchControllerWriteCommands
Hanging-get method to receive controller write commands from the device. address and
size specify the register range to monitor for commands. Multiple overlapping calls to
this method are not allowed.
Returns INVALID_ARGS if address or size are invalid, or BAD_STATE if another call
is pending for this register range. Returns CANCELED if
CancelWatchControllerWriteCommands() was called for this register range.
If this method is meant to keep the system awake (prevents suspension) while watch is setup,
use the passed-in setup_wake_lease LeaseToken. Then, when the watch is triggered this
method will return a second wake_lease LeaseToken to prevent suspension.
These keep alive wake lease tokens are provided by the Power Framework’s System Activity
Governor. A driver supporting keep alive must be able to get wake_lease from System
Activity Governor.
When wake_lease is closed, then the created wake lease keeping the system from suspending
at the time of watch triggering is dropped. Hence, to guarantee that the system is not
suspended by the Power Framework a client must either keep this wake_lease for as long as
the system needs to stay awake, or a client must get its own wake lease from the Power
Framework before it drops wake_lease to prevent suspension.
Fields
responder: DeviceWatchControllerWriteCommandsResponderCancelWatchControllerWriteCommands
Cancels an pending call to WatchControllerWriteCommands. address and size must
exactly match a previous call to WatchControllerWriteCommands(), otherwise NOT_FOUND
is returned.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
control_handle: DeviceControlHandlemethod_type: MethodTypeImplementations
Sourceimpl DeviceRequest
impl DeviceRequest
pub fn into_register_read( self, ) -> Option<(u16, u32, DeviceRegisterReadResponder)>
pub fn into_register_write( self, ) -> Option<(u16, Vec<u8>, DeviceRegisterWriteResponder)>
pub fn into_get_properties(self) -> Option<DeviceGetPropertiesResponder>
pub fn into_watch_controller_write_commands( self, ) -> Option<(u8, u16, Option<EventPair>, DeviceWatchControllerWriteCommandsResponder)>
pub fn into_cancel_watch_controller_write_commands( self, ) -> Option<(u8, u16, DeviceCancelWatchControllerWriteCommandsResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL